==> thx_i18n-0.1.2-py3-none-any.whl: thx/i18n/api/version1/views.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import exceptions, viewsets
from rest_framework.decorators import action
from rest_framework.response import Response
from thx.api.mixins import ThuxModelMixin

from ... import models
from . import serializers

STATUS_CODES = ((0, _('disable')), (1, _('enable')),)


# LANGUAGE
class LanguageViewSet(ThuxModelMixin, viewsets.ModelViewSet):
    """
    LanguageViewSet
    -----------

    :action list: Return the language list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given language.
        `Profiles`: `superuser`, `staff`

    :action light: Return the language list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new language instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a language instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a language instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a language instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.Language.objects.all()
    serializer_class = serializers.LanguageSerializer

    def get_queryset(self):
        user = self.request.user
        profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        if user.is_superuser and profile == 'superuser':
            return qs
        if user.is_staff and profile == 'staff':
            return qs
        return qs.none()

    def check_permissions(self, request):
        super().check_permissions(request)
        user = self.request.user
        profile = self.kwargs.get('profile')
        if user.is_superuser and profile == 'superuser':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable', 'light',
                'status_choices'
            ]:
                return
        if user.is_staff and profile == 'staff':
            if self.action in [
                'list', 'retrieve', 'create', 'update', 'partial_update', 'destroy', 'enable', 'disable', 'light',
                'status_choices'
            ]:
                return
        raise exceptions.PermissionDenied()

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Language{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a language instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a language instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)

==> thx_i18n-0.1.4-py3-none-any.whl: thx/i18n/api/version1/views.py <==
# -*- coding: utf-8 -*-
from django.utils.translation import gettext_lazy as _
from rest_framework import viewsets
from rest_framework.decorators import action
from rest_framework.response import Response
from thx.api.mixins import ThuxModelMixin
from thx.role.core.views import ThuxRoleViewSetMixin

from ... import models
from . import serializers, filters, permissions

STATUS_CODES = ((0, _('disable')), (1, _('enable')),)


# LANGUAGE
class LanguageViewSet(ThuxRoleViewSetMixin, ThuxModelMixin, viewsets.ModelViewSet):
    """
    LanguageViewSet
    -----------

    :action list: Return the language list.
        `Profiles`: `superuser`, `staff`

    :action retrieve: Return the given language.
        `Profiles`: `superuser`, `staff`

    :action light: Return the language list using light serialization.
        `Profiles`: `superuser`, `staff`

    :action create: Create a new language instance.
        `Profiles`: `superuser`, `staff`

    :action update: Update a language instance.
        `Profiles`: `superuser`, `staff`

    :action partial_update: Patch a language instance.
        `Profiles`: `superuser`, `staff`

    :action destroy: Delete a language instance.
        `Profiles`: `superuser`, `staff`
    """
    queryset = models.Language.objects.all()
    serializer_class = serializers.LanguageSerializer
    filter_backends = (filters.LanguageFilterBackend,)
    permission_classes = (permissions.LanguagePermission,)

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        """
        Enable a language instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        """
        Disable a language instance.
        `Profiles`: `superuser`, `staff`
        """
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path="status-choices")
    def status_choices(self, request, *args, **kwargs):
        """
        Return the status choices options.
        `Profiles`: `superuser`, `staff`
        """
        return Response(STATUS_CODES)
